Command line interface
======================

``f90nml`` includes a command line tool which can be used to modify namelist
variables inside of a shell environment.  It can also be used to convert data
between namelists and the JSON and YAML formats.

Options
-------

.. include:: cli_flags.rst


Examples
--------

.. include:: cli_examples.rst
